@@ -533,7 +533,7 @@ def catchArgparseBug(string: str | None) -> bool:
 
     if isinstance(string, str) and string.startswith("--") and "=" in string:
         m.die(
-            "You're hitting a bug with Python's argparse library. Please specify both the input and output filenames manually, and move all command-line flags with spaces in their values to after those arguments.\nSee <https://tabatkins.github.io/bikeshed/#md-issues> for details."
+            "You're hitting a bug with Python's argparse library. Please specify both the input and output filenames manually, and move all command-line flags with spaces in their values to after those arguments.\nSee <https://speced.github.io/bikeshed/#md-issues> for details."
         )
         return False
     return True
